pub struct ModemStatus(/* private fields */);Implementations
Sourceimpl ModemStatus
impl ModemStatus
Sourcepub const CLEAR_TO_SEND_CHANGED: Self
pub const CLEAR_TO_SEND_CHANGED: Self
Data Clear To Send (DCTS) indicator.
Sourcepub const DATA_SET_READY_CHANGED: Self
pub const DATA_SET_READY_CHANGED: Self
Delta Data Set Ready (DDSR) indicator.
Sourcepub const TRAILING_EDGE_RING_INDICATOR: Self
pub const TRAILING_EDGE_RING_INDICATOR: Self
Trailing Edge of Ring Indicator (TERI) detector. The RI line has changed from low to high state.
Sourcepub const CARRIER_DETECT_CHANGE: Self
pub const CARRIER_DETECT_CHANGE: Self
Delta Data Carrier Detect (DDCD) indicator.
Sourcepub const CLEAR_TO_SEND: Self
pub const CLEAR_TO_SEND: Self
Complement of the CTS input, or RTS in loopback mode.
Sourcepub const DATA_SET_READY: Self
pub const DATA_SET_READY: Self
Complement of the DSR input, or DTR in loopback mode.
Sourcepub const RING_INDICATOR: Self
pub const RING_INDICATOR: Self
Complement of the RI input, or AUX1 in loopback mode.
Sourcepub const CARRIER_DETECT: Self
pub const CARRIER_DETECT: Self
Complement of the RI input, or AUX2 in loopback mode.
Sourceimpl ModemStatus
impl ModemStatus
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<Self>
pub const fn from_bits(bits: u8) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> Self
pub const fn from_bits_truncate(bits: u8) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> Self
pub const fn from_bits_retain(bits: u8) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl ModemStatus
impl ModemStatus
Sourcepub const fn iter(&self) -> Iter<ModemStatus>
pub const fn iter(&self) -> Iter<ModemStatus>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ModemStatus>
pub const fn iter_names(&self) -> IterNames<ModemStatus>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.